bayespy.nodes.GaussianGammaISO.broadcasting_multiplier
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaISO.broadcasting_multiplier